# Configure Workspace for Meta Model v4
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#overview)
  * [Rename Three Existing Fact Sheet Types](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#rename-three-existing-fact-sheet-types)
  * [Introduce New Fact Sheet Type - Platform](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#introduce-new-fact-sheet-type---platform)
  * [1. Create a New Fact Sheet Type](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#1.-create-a-new-fact-sheet-type)
  * [2. Add Sections - Strategic Support and Implementation](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#2.-add-sections---strategic-support-and-implementation)
  * [3. Create Relations to Business Capability, Initiative, and Objective](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#3.-create-relations-to-business-capability,-initiative,-and-objective)
  * [4. Create Relations to Application and IT Component](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#4.-create-relations-to-application-and-it-component)
  * [Add Fact Sheet Subtypes to Several Fact Sheet Types](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4#add-fact-sheet-subtypes-to-several-fact-sheet-types)


View all
Learn how to configure your workspace to align with the Meta Model v4.
**Caution**
Before making any Meta Model configuration changes, make sure you have thoroughly assessed your current configuration and detected a clear use case for implementing the whole or parts of the [Meta Model v4](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
